@@ -496,6 +496,10 @@ class ArgumentsProfile(object):
                (self.kwargs == other.kwargs)
     
     
+    def __ne__(self, other):
+        return not self == other
+    
+    
     def __hash__(self):
         return self._hash
                     
