@@ -1,4 +1,4 @@
-# Copyright 2009-2012 Ram Rachum.
+# Copyright 2009-2013 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''Testing module for `python_toolbox.caching.CachedProperty`.'''
@@ -177,4 +177,12 @@ def test_decorating():
         assert a.my_method(y=7, x=8) == (8, 7, 2)
         with a.reentrant_context_manager:
             assert a.my_method(y=7, x=8) == (8, 7, 3)
-        
\ No newline at end of file
+        
+def test_force_value_not_getter():
+    class A(object):
+        personality = CachedProperty(counting_func,
+                                     force_value_not_getter=True)
+        
+    a = A()
+    assert a.personality == counting_func == a.personality == counting_func
+    
\ No newline at end of file
